@@ -1,3 +1,4 @@
+import { is_empty } from "./lib/objects";
 import type { Validator } from "./lib/validation";
 import {
   array,
@@ -12,35 +13,46 @@ import {
   union,
 } from "./lib/validation";
 
-export interface Posting {
+const entry_meta_validator = record(
+  defaultValue(
+    union(boolean, number, string),
+    () => "Unsupported metadata value",
+  ),
+);
+
+/** A posting. */
+export class Posting {
   account: string;
   amount: string;
   meta: EntryMetadata;
+
+  constructor() {
+    this.account = "";
+    this.amount = "";
+    this.meta = {};
+  }
+
+  is_empty(): boolean {
+    return !this.account && !this.amount && is_empty(this.meta);
+  }
+
+  private static raw_validator = object({
+    account: string,
+    amount: string,
+    meta: defaultValue(entry_meta_validator, () => ({})),
+  });
+
+  static validator: Validator<Posting> = (json) =>
+    Posting.raw_validator(json).map((value) =>
+      Object.assign(new Posting(), value),
+    );
 }
 
-const entry_meta_validator = record(
-  defaultValue(union(boolean, number, string), "Unsupported metadata value"),
-);
-
-const postingValidator = object({
-  account: string,
-  amount: string,
-  meta: entry_meta_validator,
-});
-
 interface Amount {
   number: string;
   currency: string;
 }
 
-export function emptyPosting(): Posting {
-  return {
-    account: "",
-    amount: "",
-    meta: {},
-  };
-}
-
 export type EntryMetadata = Record<string, string | boolean | number>;
 export type EntryTypeName =
   | "Balance"
@@ -201,7 +213,7 @@ export class Transaction extends EntryBase {
     this.narration = "";
     this.tags = [];
     this.links = [];
-    this.postings = [emptyPosting(), emptyPosting()];
+    this.postings = [];
   }
 
   toString(): string {
@@ -212,7 +224,16 @@ export class Transaction extends EntryBase {
     );
   }
 
-  private static raw_validator = object<Omit<Transaction, "toString">>({
+  toJSON(): this {
+    return {
+      ...this,
+      postings: this.postings.filter((p) => !p.is_empty()),
+    };
+  }
+
+  private static raw_validator = object<
+    Omit<Transaction, "toString" | "toJSON">
+  >({
     ...validatorBase,
     t: constant("Transaction"),
     flag: string,
@@ -220,7 +241,7 @@ export class Transaction extends EntryBase {
     narration: optional_string,
     tags: array(string),
     links: array(string),
-    postings: array(postingValidator),
+    postings: array(Posting.validator),
   });
 
   static validator: Validator<Transaction> = (json) =>
