@@ -13,7 +13,7 @@ function getScriptTagJSON(selector: string): Result<unknown, string> {
     return err(`<script> tag not found for selector '${selector}'`);
   }
   try {
-    return parseJSON(el.innerHTML);
+    return parseJSON(el.textContent ?? "");
   } catch (e) {
     return err(`<script> tag for selector '${selector}' contains invalid JSON`);
   }
@@ -26,11 +26,7 @@ function getScriptTagJSON(selector: string): Result<unknown, string> {
  */
 export function getScriptTagValue<T>(
   selector: string,
-  validator: Validator<T>
+  validator: Validator<T>,
 ): Result<T, string> {
-  const res = getScriptTagJSON(selector);
-  if (!res.success) {
-    return res;
-  }
-  return validator(res.value);
+  return getScriptTagJSON(selector).and_then(validator);
 }
