@@ -19,8 +19,7 @@ export function fuzzytest(pattern: string, text: string): number {
   let score = 0;
   let localScore = 0;
   let pindex = 0;
-  for (let index = 0; index < text.length; index += 1) {
-    const char = text[index];
+  for (const char of text) {
     const search = pattern[pindex];
     if (char === search || char.toLowerCase() === search) {
       pindex += 1;
@@ -36,7 +35,10 @@ export function fuzzytest(pattern: string, text: string): number {
 /**
  * Filter a list of possible suggestions to only those that match the pattern
  */
-export function fuzzyfilter(pattern: string, suggestions: string[]): string[] {
+export function fuzzyfilter(
+  pattern: string,
+  suggestions: readonly string[],
+): readonly string[] {
   if (!pattern) {
     return suggestions;
   }
@@ -53,7 +55,8 @@ const escapeChars: Record<string, string> = {
   "<": "&lt;",
   ">": "&gt;",
 };
-const e = (text: string) => text.replace(/["'&<>]/g, (m) => escapeChars[m]);
+const e = (text: string) =>
+  text.replace(/["'&<>]/g, (m) => escapeChars[m] ?? m);
 
 /**
  * Wrap fuzzy matched characters.
@@ -78,8 +81,7 @@ export function fuzzywrap(pattern: string, text: string): string {
   let pindex = 0;
   let inMatch = false;
   const result = [];
-  for (let index = 0; index < text.length; index += 1) {
-    const char = text[index];
+  for (const char of text) {
     const search = pattern[pindex];
     if (char === search || char.toLowerCase() === search) {
       if (!inMatch) {
