@@ -4,12 +4,12 @@ import { err, ok } from "./result";
 /**
  * Parse a JSON string into an object.
  */
-export function parseJSON(data: string): Result<unknown, "JSON syntax error"> {
+export function parseJSON(data: string): Result<unknown, string> {
   try {
     return ok(JSON.parse(data));
   } catch (error) {
     if (error instanceof SyntaxError) {
-      return err("JSON syntax error" as const);
+      return err(`JSON syntax error: ${error.message}`);
     }
     throw error;
   }
