@@ -2,9 +2,9 @@
 
 from __future__ import annotations
 
+import os
 import re
 import threading
-from codecs import decode
 from codecs import encode
 from dataclasses import replace
 from hashlib import sha256
@@ -42,7 +42,7 @@ if TYPE_CHECKING:  # pragma: no cover
     from fava.core.fava_options import InsertEntryOption
 
 #: The flags to exclude when rendering entries.
-EXCL_FLAGS = {
+_EXCL_FLAGS = {
     FLAG_PADDING,  # P
     FLAG_SUMMARIZE,  # S
     FLAG_TRANSFER,  # T
@@ -53,7 +53,7 @@ EXCL_FLAGS = {
 }
 
 
-def sha256_str(val: str) -> str:
+def _sha256_str(val: str) -> str:
     """Hash a string."""
     return sha256(encode(val, encoding="utf-8")).hexdigest()
 
@@ -81,12 +81,23 @@ class InvalidUnicodeError(FavaAPIError):
         )
 
 
+def _file_newline_character(path: Path) -> str:
+    """Get the newline character of the file by looking at the first line."""
+    with path.open("rb") as file:
+        firstline = file.readline()
+        if firstline.endswith(b"\r\n"):
+            return "\r\n"
+        if firstline.endswith(b"\n"):
+            return "\n"
+        return os.linesep
+
+
 class FileModule(FavaModule):
     """Functions related to reading/writing to Beancount files."""
 
     def __init__(self, ledger: FavaLedger) -> None:
         super().__init__(ledger)
-        self.lock = threading.Lock()
+        self._lock = threading.Lock()
 
     def get_source(self, path: Path) -> tuple[str, str]:
         """Get source files.
@@ -104,16 +115,12 @@ class FileModule(FavaModule):
         if str(path) not in self.ledger.options["include"]:
             raise NonSourceFileError(path)
 
-        with path.open(mode="rb") as file:
-            contents = file.read()
-
-        sha256sum = sha256(contents).hexdigest()
         try:
-            source = decode(contents)
+            source = path.read_text("utf-8")
         except UnicodeDecodeError as exc:
             raise InvalidUnicodeError(str(exc)) from exc
 
-        return source, sha256sum
+        return source, _sha256_str(source)
 
     def set_source(self, path: Path, source: str, sha256sum: str) -> str:
         """Write to source file.
@@ -130,19 +137,20 @@ class FileModule(FavaModule):
             FavaAPIError: If the file at `path` is not one of the
                 source files or if the file was changed externally.
         """
-        with self.lock:
+        with self._lock:
             _, original_sha256sum = self.get_source(path)
             if original_sha256sum != sha256sum:
                 raise ExternallyChangedError(path)
 
-            contents = encode(source, encoding="utf-8")
-            with path.open("w+b") as file:
-                file.write(contents)
+            newline = _file_newline_character(path)
+            with path.open("w", encoding="utf-8", newline=newline) as file:
+                file.write(source)
+            self.ledger.watcher.notify(path)
 
             self.ledger.extensions.after_write_source(str(path), source)
             self.ledger.load_file()
 
-            return sha256(contents).hexdigest()
+            return _sha256_str(source)
 
     def insert_metadata(
         self,
@@ -153,20 +161,21 @@ class FileModule(FavaModule):
         """Insert metadata into a file at lineno.
 
         Also, prevent duplicate keys.
+
+        Args:
+            entry_hash: Hash of an entry.
+            basekey: Key to insert metadata for.
+            value: Metadate value to insert.
         """
-        with self.lock:
+        with self._lock:
             self.ledger.changed()
-            entry: Directive = self.ledger.get_entry(entry_hash)
+            entry = self.ledger.get_entry(entry_hash)
             key = next_key(basekey, entry.meta)
             indent = self.ledger.fava_options.indent
             filename, lineno = get_position(entry)
-            insert_metadata_in_file(
-                Path(filename),
-                lineno,
-                indent,
-                key,
-                value,
-            )
+            path = Path(filename)
+            insert_metadata_in_file(path, lineno, indent, key, value)
+            self.ledger.watcher.notify(path)
             self.ledger.extensions.after_insert_metadata(entry, key, value)
 
     def save_entry_slice(
@@ -178,7 +187,7 @@ class FileModule(FavaModule):
         """Save slice of the source file for an entry.
 
         Args:
-            entry_hash: An entry.
+            entry_hash: Hash of an entry.
             source_slice: The lines that the entry should be replaced with.
             sha256sum: The sha256sum of the current lines of the entry.
 
@@ -188,25 +197,27 @@ class FileModule(FavaModule):
         Raises:
             FavaAPIError: If the entry is not found or the file changed.
         """
-        with self.lock:
+        with self._lock:
             entry = self.ledger.get_entry(entry_hash)
-            ret = save_entry_slice(entry, source_slice, sha256sum)
+            new_sha256sum = save_entry_slice(entry, source_slice, sha256sum)
+            self.ledger.watcher.notify(Path(get_position(entry)[0]))
             self.ledger.extensions.after_entry_modified(entry, source_slice)
-            return ret
+            return new_sha256sum
 
     def delete_entry_slice(self, entry_hash: str, sha256sum: str) -> None:
         """Delete slice of the source file for an entry.
 
         Args:
-            entry_hash: An entry.
+            entry_hash: Hash of an entry.
             sha256sum: The sha256sum of the current lines of the entry.
 
         Raises:
             FavaAPIError: If the entry is not found or the file changed.
         """
-        with self.lock:
+        with self._lock:
             entry = self.ledger.get_entry(entry_hash)
             delete_entry_slice(entry, sha256sum)
+            self.ledger.watcher.notify(Path(get_position(entry)[0]))
             self.ledger.extensions.after_delete_entry(entry)
 
     def insert_entries(self, entries: list[Directive]) -> None:
@@ -215,20 +226,19 @@ class FileModule(FavaModule):
         Args:
             entries: A list of entries.
         """
-        with self.lock:
+        with self._lock:
             self.ledger.changed()
             fava_options = self.ledger.fava_options
-            for entry in sorted(entries, key=incomplete_sortkey):
-                insert_options = fava_options.insert_entry
-                currency_column = fava_options.currency_column
-                indent = fava_options.indent
-                fava_options.insert_entry = insert_entry(
+            for entry in sorted(entries, key=_incomplete_sortkey):
+                path, updated_insert_options = insert_entry(
                     entry,
                     self.ledger.beancount_file_path,
-                    insert_options,
-                    currency_column,
-                    indent,
+                    insert_options=fava_options.insert_entry,
+                    currency_column=fava_options.currency_column,
+                    indent=fava_options.indent,
                 )
+                self.ledger.watcher.notify(path)
+                self.ledger.fava_options.insert_entry = updated_insert_options
                 self.ledger.extensions.after_insert_entry(entry)
 
     def render_entries(self, entries: list[Directive]) -> Iterable[Markup]:
@@ -245,7 +255,10 @@ class FileModule(FavaModule):
         indent = self.ledger.fava_options.indent
         for entry in entries:
             if isinstance(entry, (Balance, Transaction)):
-                if isinstance(entry, Transaction) and entry.flag in EXCL_FLAGS:
+                if (
+                    isinstance(entry, Transaction)
+                    and entry.flag in _EXCL_FLAGS
+                ):
                     continue
                 try:
                     yield Markup(get_entry_slice(entry)[0] + "\n")
@@ -259,7 +272,7 @@ class FileModule(FavaModule):
                     )
 
 
-def incomplete_sortkey(entry: Directive) -> tuple[datetime.date, int]:
+def _incomplete_sortkey(entry: Directive) -> tuple[datetime.date, int]:
     """Sortkey for entries that might have incomplete metadata."""
     if isinstance(entry, Open):
         return (entry.date, -2)
@@ -287,8 +300,8 @@ def insert_metadata_in_file(
         contents = file.readlines()
 
     contents.insert(lineno, f'{" " * indent}{key}: "{value}"\n')
-
-    with path.open("w", encoding="utf-8") as file:
+    newline = _file_newline_character(path)
+    with path.open("w", encoding="utf-8", newline=newline) as file:
         file.write("".join(contents))
 
 
@@ -329,7 +342,7 @@ def get_entry_slice(entry: Directive) -> tuple[str, str]:
     entry_lines = find_entry_lines(lines, lineno - 1)
     entry_source = "".join(entry_lines).rstrip("\n")
 
-    return entry_source, sha256_str(entry_source)
+    return entry_source, _sha256_str(entry_source)
 
 
 def save_entry_slice(
@@ -359,7 +372,7 @@ def save_entry_slice(
     first_entry_line = lineno - 1
     entry_lines = find_entry_lines(lines, first_entry_line)
     entry_source = "".join(entry_lines).rstrip("\n")
-    if sha256_str(entry_source) != sha256sum:
+    if _sha256_str(entry_source) != sha256sum:
         raise ExternallyChangedError(path)
 
     lines = (
@@ -367,13 +380,17 @@ def save_entry_slice(
         + [source_slice + "\n"]
         + lines[first_entry_line + len(entry_lines) :]
     )
-    with path.open("w", encoding="utf-8") as file:
+    newline = _file_newline_character(path)
+    with path.open("w", encoding="utf-8", newline=newline) as file:
         file.writelines(lines)
 
-    return sha256_str(source_slice)
+    return _sha256_str(source_slice)
 
 
-def delete_entry_slice(entry: Directive, sha256sum: str) -> None:
+def delete_entry_slice(
+    entry: Directive,
+    sha256sum: str,
+) -> None:
     """Delete slice of the source file for an entry.
 
     Args:
@@ -392,7 +409,7 @@ def delete_entry_slice(entry: Directive, sha256sum: str) -> None:
     first_entry_line = lineno - 1
     entry_lines = find_entry_lines(lines, first_entry_line)
     entry_source = "".join(entry_lines).rstrip("\n")
-    if sha256_str(entry_source) != sha256sum:
+    if _sha256_str(entry_source) != sha256sum:
         raise ExternallyChangedError(path)
 
     # Also delete the whitespace following this entry
@@ -406,7 +423,8 @@ def delete_entry_slice(entry: Directive, sha256sum: str) -> None:
             break
         last_entry_line += 1
     lines = lines[:first_entry_line] + lines[last_entry_line:]
-    with path.open("w", encoding="utf-8") as file:
+    newline = _file_newline_character(path)
+    with path.open("w", encoding="utf-8", newline=newline) as file:
         file.writelines(lines)
 
 
@@ -416,7 +434,7 @@ def insert_entry(
     insert_options: list[InsertEntryOption],
     currency_column: int,
     indent: int,
-) -> list[InsertEntryOption]:
+) -> tuple[Path, list[InsertEntryOption]]:
     """Insert an entry.
 
     Args:
@@ -427,7 +445,7 @@ def insert_entry(
         indent: Number of indent spaces.
 
     Returns:
-        A list of updated insert options.
+        A changed path and list of updated insert options.
     """
     filename, lineno = find_insert_position(
         entry,
@@ -446,21 +464,25 @@ def insert_entry(
     else:
         contents.insert(lineno, content + "\n")
 
-    with path.open("w", encoding="utf-8") as file:
+    newline = _file_newline_character(path)
+    with path.open("w", encoding="utf-8", newline=newline) as file:
         file.writelines(contents)
 
     if lineno is None:
-        return insert_options
+        return (path, insert_options)
 
     added_lines = content.count("\n") + 1
-    return [
-        (
-            replace(option, lineno=option.lineno + added_lines)
-            if option.filename == filename and option.lineno > lineno
-            else option
-        )
-        for option in insert_options
-    ]
+    return (
+        path,
+        [
+            (
+                replace(option, lineno=option.lineno + added_lines)
+                if option.filename == filename and option.lineno > lineno
+                else option
+            )
+            for option in insert_options
+        ],
+    )
 
 
 def find_insert_position(
