@@ -16,7 +16,7 @@ from fava.core.conversion import cost_or_value
 from fava.ext import FavaExtensionBase
 from fava.helpers import FavaAPIError
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from fava.beans.funcs import ResultType
     from fava.core.tree import Tree
     from fava.core.tree import TreeNode
@@ -121,7 +121,7 @@ class PortfolioList(FavaExtensionBase):  # pragma: no cover
             and regexer.match(str(entry.meta[metadata_key]))
         ]
         return Portfolio(
-            f"Accounts with '{metadata_key}' metadata matching: '{pattern }'",
+            f"Accounts with '{metadata_key}' metadata matching: '{pattern}'",
             self._portfolio_data(selected_nodes),
         )
 
