@@ -1,11 +1,17 @@
-# pylint: disable=missing-docstring
-import pytest
-from beancount.query.query import run_query
+from __future__ import annotations
 
+from typing import TYPE_CHECKING
+
+import pytest
+
+from fava.beans.funcs import run_query
 from fava.util import excel
 
+if TYPE_CHECKING:  # pragma: no cover
+    from fava.core import FavaLedger
 
-def test_to_csv(example_ledger):
+
+def test_to_csv(example_ledger: FavaLedger) -> None:
     types, rows = run_query(
         example_ledger.all_entries,
         example_ledger.options,
@@ -23,7 +29,7 @@ def test_to_csv(example_ledger):
 
 
 @pytest.mark.skipif(not excel.HAVE_EXCEL, reason="pyexcel not installed")
-def test_to_excel(example_ledger):
+def test_to_excel(example_ledger: FavaLedger) -> None:
     types, rows = run_query(
         example_ledger.all_entries,
         example_ledger.options,
